# PiWaterflow
This is a resilient watering system, executed in a Raspberry Pi to control irrigation valves using relays.
It's intended to be executed periodically (i.e. cron every 5 minutes).
It supports 2 watering programs every day.
